@@ -12,7 +12,7 @@ Usage::
     client: AppConfigClient = boto3.client("appconfig")
     ```
 """
-from typing import IO, Any, Dict, List, Type, Union
+from typing import IO, Any, Dict, Mapping, Sequence, Type, Union
 
 from botocore.client import BaseClient, ClientMeta
 from botocore.response import StreamingBody
@@ -43,7 +43,7 @@ __all__ = ("AppConfigClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -60,7 +60,7 @@ class Exceptions:
 
 class AppConfigClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html)
     """
 
@@ -76,18 +76,18 @@ class AppConfigClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#can_paginate)
         """
 
     def create_application(
-        self, *, Name: str, Description: str = None, Tags: Dict[str, str] = None
+        self, *, Name: str, Description: str = None, Tags: Mapping[str, str] = None
     ) -> ApplicationResponseMetadataTypeDef:
         """
         An application in AppConfig is a logical unit of code that provides capabilities
         for your customers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.create_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.create_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#create_application)
         """
 
@@ -99,13 +99,13 @@ class AppConfigClient(BaseClient):
         LocationUri: str,
         Description: str = None,
         RetrievalRoleArn: str = None,
-        Validators: List["ValidatorTypeDef"] = None,
-        Tags: Dict[str, str] = None
+        Validators: Sequence["ValidatorTypeDef"] = None,
+        Tags: Mapping[str, str] = None
     ) -> ConfigurationProfileTypeDef:
         """
         Information that enables AppConfig to access the configuration source.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.create_configuration_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.create_configuration_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#create_configuration_profile)
         """
 
@@ -119,13 +119,13 @@ class AppConfigClient(BaseClient):
         Description: str = None,
         FinalBakeTimeInMinutes: int = None,
         GrowthType: GrowthTypeType = None,
-        Tags: Dict[str, str] = None
+        Tags: Mapping[str, str] = None
     ) -> DeploymentStrategyResponseMetadataTypeDef:
         """
         A deployment strategy defines important criteria for rolling out your
         configuration to the designated targets.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.create_deployment_strategy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.create_deployment_strategy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#create_deployment_strategy)
         """
 
@@ -135,13 +135,13 @@ class AppConfigClient(BaseClient):
         ApplicationId: str,
         Name: str,
         Description: str = None,
-        Monitors: List["MonitorTypeDef"] = None,
-        Tags: Dict[str, str] = None
+        Monitors: Sequence["MonitorTypeDef"] = None,
+        Tags: Mapping[str, str] = None
     ) -> EnvironmentResponseMetadataTypeDef:
         """
         For each application, you define one or more environments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.create_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.create_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#create_environment)
         """
 
@@ -158,7 +158,7 @@ class AppConfigClient(BaseClient):
         """
         Create a new configuration in the AppConfig configuration store.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.create_hosted_configuration_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.create_hosted_configuration_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#create_hosted_configuration_version)
         """
 
@@ -166,7 +166,7 @@ class AppConfigClient(BaseClient):
         """
         Delete an application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.delete_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.delete_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#delete_application)
         """
 
@@ -176,7 +176,7 @@ class AppConfigClient(BaseClient):
         """
         Delete a configuration profile.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.delete_configuration_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.delete_configuration_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#delete_configuration_profile)
         """
 
@@ -184,7 +184,7 @@ class AppConfigClient(BaseClient):
         """
         Delete a deployment strategy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.delete_deployment_strategy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.delete_deployment_strategy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#delete_deployment_strategy)
         """
 
@@ -192,7 +192,7 @@ class AppConfigClient(BaseClient):
         """
         Delete an environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.delete_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.delete_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#delete_environment)
         """
 
@@ -202,21 +202,21 @@ class AppConfigClient(BaseClient):
         """
         Delete a version of a configuration from the AppConfig configuration store.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.delete_hosted_configuration_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.delete_hosted_configuration_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#delete_hosted_configuration_version)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#generate_presigned_url)
         """
 
@@ -224,7 +224,7 @@ class AppConfigClient(BaseClient):
         """
         Retrieve information about an application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.get_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.get_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_application)
         """
 
@@ -240,7 +240,7 @@ class AppConfigClient(BaseClient):
         """
         Receive information about a configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.get_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.get_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_configuration)
         """
 
@@ -250,7 +250,7 @@ class AppConfigClient(BaseClient):
         """
         Retrieve information about a configuration profile.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.get_configuration_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.get_configuration_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_configuration_profile)
         """
 
@@ -260,7 +260,7 @@ class AppConfigClient(BaseClient):
         """
         Retrieve information about a configuration deployment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.get_deployment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.get_deployment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_deployment)
         """
 
@@ -270,7 +270,7 @@ class AppConfigClient(BaseClient):
         """
         Retrieve information about a deployment strategy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.get_deployment_strategy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.get_deployment_strategy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_deployment_strategy)
         """
 
@@ -280,7 +280,7 @@ class AppConfigClient(BaseClient):
         """
         Retrieve information about an environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.get_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.get_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_environment)
         """
 
@@ -290,7 +290,7 @@ class AppConfigClient(BaseClient):
         """
         Get information about a specific configuration version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.get_hosted_configuration_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.get_hosted_configuration_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#get_hosted_configuration_version)
         """
 
@@ -300,7 +300,7 @@ class AppConfigClient(BaseClient):
         """
         List all applications in your AWS account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.list_applications)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.list_applications)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_applications)
         """
 
@@ -310,7 +310,7 @@ class AppConfigClient(BaseClient):
         """
         Lists the configuration profiles for an application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.list_configuration_profiles)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.list_configuration_profiles)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_configuration_profiles)
         """
 
@@ -320,7 +320,7 @@ class AppConfigClient(BaseClient):
         """
         List deployment strategies.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.list_deployment_strategies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.list_deployment_strategies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_deployment_strategies)
         """
 
@@ -335,7 +335,7 @@ class AppConfigClient(BaseClient):
         """
         Lists the deployments for an environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.list_deployments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.list_deployments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_deployments)
         """
 
@@ -345,7 +345,7 @@ class AppConfigClient(BaseClient):
         """
         List the environments for an application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.list_environments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.list_environments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_environments)
         """
 
@@ -361,7 +361,7 @@ class AppConfigClient(BaseClient):
         View a list of configurations stored in the AppConfig configuration store by
         version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.list_hosted_configuration_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.list_hosted_configuration_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_hosted_configuration_versions)
         """
 
@@ -369,7 +369,7 @@ class AppConfigClient(BaseClient):
         """
         Retrieves the list of key-value tags assigned to the resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#list_tags_for_resource)
         """
 
@@ -382,12 +382,12 @@ class AppConfigClient(BaseClient):
         ConfigurationProfileId: str,
         ConfigurationVersion: str,
         Description: str = None,
-        Tags: Dict[str, str] = None
+        Tags: Mapping[str, str] = None
     ) -> DeploymentTypeDef:
         """
         Starts a deployment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.start_deployment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.start_deployment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#start_deployment)
         """
 
@@ -397,23 +397,23 @@ class AppConfigClient(BaseClient):
         """
         Stops a deployment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.stop_deployment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.stop_deployment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#stop_deployment)
         """
 
-    def tag_resource(self, *, ResourceArn: str, Tags: Dict[str, str]) -> None:
+    def tag_resource(self, *, ResourceArn: str, Tags: Mapping[str, str]) -> None:
         """
         Metadata to assign to an AppConfig resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceArn: str, TagKeys: List[str]) -> None:
+    def untag_resource(self, *, ResourceArn: str, TagKeys: Sequence[str]) -> None:
         """
         Deletes a tag key and value from an AppConfig resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#untag_resource)
         """
 
@@ -423,7 +423,7 @@ class AppConfigClient(BaseClient):
         """
         Updates an application.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.update_application)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.update_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#update_application)
         """
 
@@ -435,12 +435,12 @@ class AppConfigClient(BaseClient):
         Name: str = None,
         Description: str = None,
         RetrievalRoleArn: str = None,
-        Validators: List["ValidatorTypeDef"] = None
+        Validators: Sequence["ValidatorTypeDef"] = None
     ) -> ConfigurationProfileTypeDef:
         """
         Updates a configuration profile.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.update_configuration_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.update_configuration_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#update_configuration_profile)
         """
 
@@ -457,7 +457,7 @@ class AppConfigClient(BaseClient):
         """
         Updates a deployment strategy.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.update_deployment_strategy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.update_deployment_strategy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#update_deployment_strategy)
         """
 
@@ -468,12 +468,12 @@ class AppConfigClient(BaseClient):
         EnvironmentId: str,
         Name: str = None,
         Description: str = None,
-        Monitors: List["MonitorTypeDef"] = None
+        Monitors: Sequence["MonitorTypeDef"] = None
     ) -> EnvironmentResponseMetadataTypeDef:
         """
         Updates an environment.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.update_environment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.update_environment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#update_environment)
         """
 
@@ -483,6 +483,6 @@ class AppConfigClient(BaseClient):
         """
         Uses the validators in a configuration profile to validate a configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.42/reference/services/appconfig.html#AppConfig.Client.validate_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.45/reference/services/appconfig.html#AppConfig.Client.validate_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appconfig/client.html#validate_configuration)
         """
